using Microsoft.EntityFrameworkCore;
using assignment2.Models;
using Microsoft.AspNetCore.Identity.EntityFrameworkCore;
using assignment1.Models;

public class ExperienceDBContext : IdentityDbContext<ApiUser>
{
    // ✅ Fallback til EF CLI, men bruger stadig ENV hvis det er sat
    private readonly string connString = Environment.GetEnvironmentVariable("DATABASE_CONNECTION_STRING")
        ?? "Server=(localdb)\\MSSQLLocalDB;Database=ExperienceDb;Trusted_Connection=True;MultipleActiveResultSets=true";

    public ExperienceDBContext(DbContextOptions<ExperienceDBContext> options) : base(options)
    {
    }

    public DbSet<Experience> Experiences { get; set; }
    public DbSet<SharedExperience> SharedExperiences { get; set; }
    public DbSet<Provider> Providers { get; set; }
    public DbSet<Discount> Discounts { get; set; }
    public DbSet<Guest> Guests { get; set; }

    protected override void OnConfiguring(DbContextOptionsBuilder optionsBuilder)
    {
        optionsBuilder.UseSqlServer(connString);
    }

    protected override void OnModelCreating(ModelBuilder modelBuilder)
    {
        base.OnModelCreating(modelBuilder); 

        modelBuilder.Entity<SharedExperience>(se =>
        {
            se.HasMany(se => se.Experiences)
              .WithMany(e => e.SharedExperiences)
              .UsingEntity(t => t.ToTable("SharedExperiencesExperiences"));
        });

        modelBuilder.Entity<Guest>(g =>
        {
            g.HasMany(g => g.Experiences)
              .WithMany(e => e.Guests)
              .UsingEntity(t => t.ToTable("GuestsExperiences"));
        });

        modelBuilder.Entity<Guest>(g =>
        {
            g.HasMany(g => g.SharedExperiences)
              .WithMany(se => se.Guests)
              .UsingEntity(t => t.ToTable("GuestsSharedExperiences"));
        });

        modelBuilder.Entity<Guest>(g =>
        {
            g.HasMany(g => g.Friends)
              .WithMany(g => g.FriendsOf)
              .UsingEntity<Dictionary<string, object>>(
                "GuestFriends",
                j => j.HasOne<Guest>().WithMany().HasForeignKey("GuestId").OnDelete(DeleteBehavior.Restrict),
                j => j.HasOne<Guest>().WithMany().HasForeignKey("FriendId").OnDelete(DeleteBehavior.Restrict),
                j =>
                {
                    j.HasKey("GuestId", "FriendId");
                    j.ToTable(table =>
                    {
                        table.Metadata.SetTableName("GuestFriends");
                        table.HasCheckConstraint("CHK_IDS_ORDER", "(GuestId < FriendId)");
                    });
                });
        });
    }
}

