using assignment1.Models;
using Microsoft.AspNetCore.Identity;

namespace assignment1.DB
{
    public static class IdentitySeeder
    {
        public static async Task SeedRolesAndUsersAsync(UserManager<ApiUser> userManager, RoleManager<IdentityRole> roleManager)
        {
            string[] roles = { "Admin", "Manager", "Provider", "Guest" };

            foreach (var role in roles)
            {
                if (!await roleManager.RoleExistsAsync(role))
                {
                    await roleManager.CreateAsync(new IdentityRole(role));
                }
            }

            var users = new[]
            {
                new { Email = "admin@example.com", Password = "Admin123!", Role = "Admin" },
                new { Email = "manager@example.com", Password = "Manager123!", Role = "Manager" },
                new { Email = "provider@example.com", Password = "Provider123!", Role = "Provider" },
                new { Email = "guest@example.com", Password = "Guest123!", Role = "Guest" },
            };

            foreach (var userInfo in users)
            {
                var existingUser = await userManager.FindByEmailAsync(userInfo.Email);
                if (existingUser == null)
                {
                    var user = new ApiUser
                    {
                        UserName = userInfo.Email,
                        Email = userInfo.Email
                    };

                    var result = await userManager.CreateAsync(user, userInfo.Password);
                    if (result.Succeeded)
                    {
                        await userManager.AddToRoleAsync(user, userInfo.Role);
                    }
                }
            }
        }
    }
}

