﻿using System.Diagnostics;
using assignment2.Interfaces;
using assignment2.Models;

public sealed class LoggerMiddleware
{
    private readonly RequestDelegate _next;
    private readonly ILogger _logger;
    private readonly ILogService _logService;

    public LoggerMiddleware(RequestDelegate next, ILogger<LoggerMiddleware> logger, ILogService logService)
    {
        _next = next;
        _logger = logger;
        _logService = logService;
    }

    public async Task Invoke(HttpContext context)
    {
        // Create a dictionary or a custom object to hold request details.
        var requestDetails = new Dictionary<string, object>
        {
            { "RequestHost", context.Request.Host.ToString() },
            { "RequestScheme", context.Request.Scheme },
            { "RequestPath", context.Request.Path.ToString() }
            // Add other details as needed
        };

        var newLog = new Log
        {
            User = context.User?.Identity?.Name ?? "Anonymous",
            Operation = context.Request.Method,
            Timestamp = DateTime.UtcNow
        };

        _logger.LogInformation("Request completed with details: {@newLog}", newLog);
        await _next(context);
    }
}