using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;
using assignment2.Interfaces;
using assignment2.Models;
using Microsoft.Extensions.Options;
using MongoDB.Driver;

namespace assignment2.Services
{
    public class LogsService : ILogService
    {
        private readonly IMongoCollection<Log> _logsCollection;

        public LogsService(IOptions<LogsDatabaseSettings> logsDatabaseSettings)
        {
            var mongoClient = new MongoClient(
                logsDatabaseSettings.Value.ConnectionString);

            var mongoDatabase = mongoClient.GetDatabase(
                logsDatabaseSettings.Value.DatabaseName);

            _logsCollection = mongoDatabase.GetCollection<Log>(
                logsDatabaseSettings.Value.LogsCollectionName);
        
        }


        public async Task<IEnumerable<Log>> GetAsync(string? user, string? operation, DateTime? startDate, DateTime? endTime)
        {

            var builder = Builders<Log>.Filter;
            var filters = new List<FilterDefinition<Log>>();

            if (!string.IsNullOrEmpty(user))
                filters.Add(builder.Eq(u => u.User, user));

            if (!string.IsNullOrEmpty(operation))
                filters.Add(builder.Eq(u => u.Operation, operation));

            if (startDate.HasValue && endTime.HasValue)
                filters.Add(builder.And(builder.Gte(u => u.Timestamp, startDate), builder.Lte(u => u.Timestamp, endTime)));

            var filter = filters.Count > 0 ? builder.And(filters) : builder.Empty;

            return await _logsCollection.Find(filter).ToListAsync();
        }

    }
}